@@ -38,6 +38,7 @@
 
 #include <farstream/fs-conference.h>
 
+#include "fs-rtp-bin-error-downgrade.h"
 #include "fs-rtp-conference.h"
 #include "fs-rtp-codec-cache.h"
 #include "fs-rtp-special-source.h"
@@ -383,7 +384,6 @@ validate_h263_codecs (CodecCap *codec_cap)
   if (!rtp_struct)
     return FALSE;
 
-  /* If there no h263version, we accept everything */
   encoding_name = gst_structure_get_string (rtp_struct, "encoding-name");
 
   /* If there is no encoding name, we have a problem, lets refuse it */
@@ -536,7 +536,7 @@ remove_duplicates (GList *list)
       if (gst_caps_is_equal (codec_cap1->rtp_caps, codec_cap2->rtp_caps))
       {
         codec_cap_free (codec_cap2);
-        walk1 = g_list_remove_link (walk1, walk2);
+        walk1 = g_list_delete_link (walk1, walk2);
         goto again;
       }
     }
@@ -639,7 +639,7 @@ parse_codec_cap_list (GList *list, FsMediaType media_type)
             codec_blueprint->send_pipeline_factory,
             g_list_append (NULL, tmpfact));
       }
-      tmpfact = gst_element_factory_find ("ffmpegcolorspace");
+      tmpfact = gst_element_factory_find ("videoconvert");
       if (tmpfact)
       {
         codec_blueprint->send_pipeline_factory = g_list_append (
@@ -913,11 +913,9 @@ codec_cap_list_intersect (GList *list1, GList *list2)
           (rtp_intersection == NULL || !gst_caps_is_empty (rtp_intersection)))
       {
         if (item) {
-          GstCaps *new_caps = gst_caps_union (item->caps, intersection);
           GList *tmplist;
 
-          gst_caps_unref (item->caps);
-          item->caps = new_caps;
+          item->caps = gst_caps_merge (item->caps, intersection);
 
           for (tmplist = g_list_first (codec_cap2->element_list1->data);
                tmplist;
@@ -933,7 +931,7 @@ codec_cap_list_intersect (GList *list1, GList *list2)
         } else {
 
           item = g_slice_new0 (CodecCap);
-          item->caps = gst_caps_ref (intersection);
+          item->caps = intersection;
 
           if (rtp_caps1 && rtp_caps2)
           {
@@ -963,15 +961,14 @@ codec_cap_list_intersect (GList *list1, GList *list2)
 
           intersection_list = g_list_append (intersection_list, item);
           if (rtp_intersection) {
-            gst_caps_unref (intersection);
             break;
           }
         }
       } else {
         if (rtp_intersection)
           gst_caps_unref (rtp_intersection);
+        gst_caps_unref (intersection);
       }
-      gst_caps_unref (intersection);
     }
   }
 
@@ -1054,12 +1051,12 @@ check_caps_compatibility (GstElementFactory *factory,
   GstStaticPadTemplate *padtemplate;
   GstCaps *padtemplate_caps = NULL;
 
-  if (!factory->numpadtemplates)
+  if (!gst_element_factory_get_num_pad_templates (factory))
   {
     return FALSE;
   }
 
-  pads = factory->staticpadtemplates;
+  pads = gst_element_factory_get_static_pad_templates (factory);
   while (pads)
   {
     padtemplate = (GstStaticPadTemplate *) (pads->data);
@@ -1110,11 +1107,8 @@ compare_media_caps (gconstpointer a, gconstpointer b)
 }
 
 static gint
-compare_rtp_caps (gconstpointer a, gconstpointer b)
+compare_rtp_caps (CodecCap *element, GstCaps *c_caps)
 {
-  CodecCap *element = (CodecCap *)a;
-  GstCaps *c_caps = (GstCaps *)b;
-
   return !gst_caps_can_intersect (element->rtp_caps, c_caps);
 }
 
@@ -1217,18 +1211,15 @@ create_codec_cap_list (GstElementFactory *factory,
       }
       else
       {
-        GstCaps *newcaps;
-
         entry->element_list1->data =
           g_list_append (entry->element_list1->data, factory);
         gst_object_ref (factory);
 
         if (rtp_caps) {
           if (entry->rtp_caps) {
-            GstCaps *new_rtp_caps;
-            new_rtp_caps = gst_caps_union (rtp_caps, entry->rtp_caps);
+            GstCaps *tmp = gst_caps_intersect (rtp_caps, entry->rtp_caps);
             gst_caps_unref (entry->rtp_caps);
-            entry->rtp_caps = new_rtp_caps;
+            entry->rtp_caps = tmp;
           } else {
             entry->rtp_caps = gst_caps_ref (rtp_caps);
             /* This shouldn't happen, its we're looking at rtp elements
@@ -1236,12 +1227,7 @@ create_codec_cap_list (GstElementFactory *factory,
             g_assert_not_reached ();
           }
         }
-
-        newcaps = gst_caps_union (cur_caps, entry->caps);
-        gst_caps_unref (entry->caps);
-        gst_caps_unref (cur_caps);
-        entry->caps = newcaps;
-
+        entry->caps = gst_caps_merge (cur_caps, entry->caps);
       }
     }
   done:
@@ -1286,7 +1272,7 @@ get_plugins_filtered_from_caps (FilterFunc filter,
   GList *list = NULL;
   GstCaps *matched_caps = NULL;
 
-  result = gst_registry_get_feature_list (gst_registry_get_default (),
+  result = gst_registry_get_feature_list (gst_registry_get (),
           GST_TYPE_ELEMENT_FACTORY);
 
   result = g_list_sort (result, (GCompareFunc) compare_ranks);
@@ -1296,7 +1282,8 @@ get_plugins_filtered_from_caps (FilterFunc filter,
     GstElementFactory *factory = GST_ELEMENT_FACTORY (walk->data);
 
     /* Ignore unranked plugins */
-    if (gst_plugin_feature_get_rank (factory) == GST_RANK_NONE)
+    if (gst_plugin_feature_get_rank (GST_PLUGIN_FEATURE (factory)) ==
+        GST_RANK_NONE)
       continue;
 
     if (!filter (factory))
@@ -1312,15 +1299,44 @@ get_plugins_filtered_from_caps (FilterFunc filter,
     else
     {
       gint i;
-      for (i = 0; i < gst_caps_get_size (matched_caps); i++)
+      GPtrArray *capslist = g_ptr_array_new_with_free_func (
+        (GDestroyNotify) gst_caps_unref);
+
+      while (gst_caps_get_size (matched_caps) > 0)
       {
-        GstCaps *cur_caps =
-            gst_caps_copy_nth (matched_caps, i);
+        GstCaps *stolencaps = gst_caps_new_full (
+          gst_caps_steal_structure (matched_caps, 0), NULL);
+        gboolean got_match = FALSE;
+
+        for (i = 0; i < capslist->len; i++)
+        {
+          GstCaps *intersect = gst_caps_intersect (stolencaps,
+              g_ptr_array_index (capslist, i));
+
+          if (gst_caps_is_empty (intersect))
+          {
+            gst_caps_unref (intersect);
+          }
+          else
+          {
+            got_match = TRUE;
+            gst_caps_unref (g_ptr_array_index (capslist, i));
+            g_ptr_array_index (capslist, i) = intersect;
+          }
+        }
+
+        if (got_match)
+          gst_caps_unref (stolencaps);
+        else
+          g_ptr_array_add (capslist, stolencaps);
 
-        list = create_codec_cap_list (factory, direction, list, cur_caps);
-        gst_caps_unref (cur_caps);
       }
       gst_caps_unref (matched_caps);
+
+      for (i = 0; i < capslist->len; i++)
+        list = create_codec_cap_list (factory, direction, list,
+            g_ptr_array_index (capslist, i));
+      g_ptr_array_unref (capslist);
     }
   }
 
@@ -1542,7 +1558,10 @@ create_codec_bin_from_blueprint (const FsCodec *codec,
 
   GST_DEBUG ("creating %s codec bin for id %d, pipeline_factory %p",
     direction_str, codec->id, pipeline_factory);
-  codec_bin = gst_bin_new (name);
+  if (is_send)
+    codec_bin = gst_bin_new (name);
+  else
+    codec_bin = fs_rtp_bin_error_downgrade_new (name);
 
   for (walk = g_list_first (pipeline_factory); walk; walk = g_list_next (walk))
   {
