@@ -467,9 +467,10 @@ build_dtmf_sound_recv_pipeline (gint *port)
   GstElement *src;
   GstBus *bus;
 
-  pipeline = gst_parse_launch (
+  pipeline = gst_parse_launch_full (
       "udpsrc name=src caps=\"application/x-rtp, payload=0\" !"
-      " rtppcmudepay ! mulawdec ! dtmfdetect ! fakesink sync=0", NULL);
+      " rtppcmudepay ! mulawdec ! dtmfdetect ! fakesink sync=0", NULL,
+      GST_PARSE_FLAG_FATAL_ERRORS, NULL);
   fail_if (pipeline == NULL);
 
   bus = gst_element_get_bus (pipeline);
