@@ -29,8 +29,6 @@
 
 #include "fs-rawudp-component.h"
 
-#include "fs-rawudp-marshal.h"
-
 #include <stun/usages/bind.h>
 #include <stun/stunagent.h>
 #include <stun/usages/timer.h>
@@ -39,12 +37,14 @@
 
 #include <farstream/fs-conference.h>
 
-#include <gst/netbuffer/gstnetbuffer.h>
+#include <gst/net/gstnetaddressmeta.h>
 
 #ifdef HAVE_GUPNP
 #include <libgupnp-igd/gupnp-simple-igd-thread.h>
 #endif
 
+#include <gio/gio.h>
+
 #include <string.h>
 #include <sys/types.h>
 
@@ -52,15 +52,6 @@
 # include <unistd.h>
 #endif
 
-#ifdef G_OS_WIN32
-# include <winsock2.h>
-#else /*G_OS_WIN32*/
-# include <netdb.h>
-# include <sys/socket.h>
-# include <netinet/in.h>
-# include <arpa/inet.h>
-#endif /*G_OS_WIN32*/
-
 #define GST_CAT_DEFAULT fs_rawudp_transmitter_debug
 
 #define DEFAULT_UPNP_MAPPING_TIMEOUT (600)
@@ -118,7 +109,7 @@ struct _FsRawUdpComponentPrivate
   guint stun_port;
   guint stun_timeout;
 
-  GMutex *mutex;
+  GMutex mutex;
 
   StunAgent stun_agent;
   StunMessage stun_message;
@@ -143,7 +134,7 @@ struct _FsRawUdpComponentPrivate
   UdpPort *udpport;
 
   FsCandidate *remote_candidate;
-  GstNetAddress remote_address;
+  GSocketAddress *remote_address;
 
   FsCandidate *local_active_candidate;
   FsCandidate *local_forced_candidate;
@@ -177,9 +168,9 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static GType type = 0;
 
 #define FS_RAWUDP_COMPONENT_LOCK(component) \
-  g_mutex_lock ((component)->priv->mutex)
+  g_mutex_lock (&(component)->priv->mutex)
 #define FS_RAWUDP_COMPONENT_UNLOCK(component) \
-  g_mutex_unlock ((component)->priv->mutex)
+  g_mutex_unlock (&(component)->priv->mutex)
 
 static void
 fs_rawudp_component_class_init (FsRawUdpComponentClass *klass);
@@ -216,16 +207,15 @@ static void
 fs_rawudp_component_emit_candidate (FsRawUdpComponent *self,
     FsCandidate *candidate);
 
-static gboolean
-stun_recv_cb (GstPad *pad, GstBuffer *buffer,
-    gpointer user_data);
+static GstPadProbeReturn
+stun_recv_cb (GstPad *pad, GstPadProbeInfo *info, gpointer user_data);
 static gpointer
 stun_timeout_func (gpointer user_data);
-static gboolean
-buffer_recv_cb (GstPad *pad, GstBuffer *buffer, gpointer user_data);
+static GstPadProbeReturn
+buffer_recv_cb (GstPad *pad, GstPadProbeInfo *info, gpointer user_data);
 
 static void
-remote_is_unique_cb (gboolean unique, const GstNetAddress *address,
+remote_is_unique_cb (gboolean unique, GSocketAddress *address,
     gpointer user_data);
 
 static gboolean
@@ -261,8 +251,6 @@ fs_rawudp_component_register_type (FsPlugin *module)
 
   /* Required because the GST type registration is not thread safe */
 
-  g_type_class_ref (GST_TYPE_NETBUFFER);
-
   type = g_type_module_register_type (G_TYPE_MODULE (module),
       G_TYPE_OBJECT, "FsRawUdpComponent", &info, 0);
 
@@ -459,10 +447,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
     ("new-active-candidate-pair",
         G_TYPE_FROM_CLASS (klass),
         G_SIGNAL_RUN_LAST,
-        0,
-        NULL,
-        NULL,
-        _fs_rawudp_marshal_VOID__BOXED_BOXED,
+        0, NULL, NULL, NULL,
         G_TYPE_NONE, 2, FS_TYPE_CANDIDATE, FS_TYPE_CANDIDATE);
 
  /**
@@ -479,10 +464,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
     ("known-source-packet-received",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
-      0,
-      NULL,
-      NULL,
-      _fs_rawudp_marshal_VOID__UINT_POINTER,
+      0, NULL, NULL, NULL,
       G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_POINTER);
 
   /**
@@ -497,10 +479,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
   signals[ERROR_SIGNAL] = g_signal_new ("error",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
-      0,
-      NULL,
-      NULL,
-      _fs_rawudp_marshal_VOID__ENUM_STRING,
+      0, NULL, NULL, NULL,
       G_TYPE_NONE, 2, FS_TYPE_ERROR, G_TYPE_STRING);
 
 
@@ -539,7 +518,7 @@ fs_rawudp_component_init (FsRawUdpComponent *self)
   self->priv->upnp_mapping_timeout = DEFAULT_UPNP_MAPPING_TIMEOUT;
 #endif
 
-  self->priv->mutex = g_mutex_new ();
+  g_mutex_init (&self->priv->mutex);
 }
 
 static void
@@ -572,8 +551,7 @@ fs_rawudp_constructed (GObject *object)
   if (self->priv->associate_on_source)
     self->priv->buffer_recv_id =
       fs_rawudp_transmitter_udpport_connect_recv (
-          self->priv->udpport,
-          G_CALLBACK (buffer_recv_cb), self);
+          self->priv->udpport, buffer_recv_cb, self);
 
   GST_CALL_PARENT (G_OBJECT_CLASS, constructed, (object));
 }
@@ -611,6 +589,8 @@ fs_rawudp_component_dispose (GObject *object)
   self->priv->transmitter = NULL;
   FS_RAWUDP_COMPONENT_UNLOCK (self);
 
+  g_clear_object (&self->priv->remote_address);
+
   g_object_unref (ts);
 
   parent_class->dispose (object);
@@ -670,7 +650,7 @@ fs_rawudp_component_stop (FsRawUdpComponent *self)
 
 
       fs_rawudp_transmitter_udpport_remove_known_address (udpport,
-          &self->priv->remote_address, remote_is_unique_cb, self);
+          self->priv->remote_address, remote_is_unique_cb, self);
     }
 
     FS_RAWUDP_COMPONENT_UNLOCK (self);
@@ -700,7 +680,7 @@ fs_rawudp_component_finalize (GObject *object)
   g_free (self->priv->ip);
   g_free (self->priv->stun_ip);
 
-  g_mutex_free (self->priv->mutex);
+  g_mutex_clear (&self->priv->mutex);
 
   parent_class->finalize (object);
 }
@@ -912,14 +892,14 @@ fs_rawudp_component_new (
 }
 
 static void
-remote_is_unique_cb (gboolean unique, const GstNetAddress *address,
+remote_is_unique_cb (gboolean unique, GSocketAddress *address,
     gpointer user_data)
 {
   FsRawUdpComponent *self = FS_RAWUDP_COMPONENT (user_data);
 
   FS_RAWUDP_COMPONENT_LOCK (self);
 
-  if (!gst_netaddress_equal (address, &self->priv->remote_address))
+  if (!fs_g_inet_socket_address_equal (address, self->priv->remote_address))
   {
     GST_ERROR ("Got callback for an address that is not ours");
     goto out;
@@ -939,9 +919,7 @@ fs_rawudp_component_set_remote_candidate (FsRawUdpComponent *self,
 {
   FsCandidate *old_candidate = NULL;
   gboolean sending;
-  struct addrinfo hints = {0};
-  struct addrinfo *res = NULL;
-  int rv;
+  GInetAddress *addr;
 
   if (candidate->component_id != self->priv->component)
   {
@@ -952,12 +930,11 @@ fs_rawudp_component_set_remote_candidate (FsRawUdpComponent *self,
     return FALSE;
   }
 
-  hints.ai_flags = AI_NUMERICHOST;
-  rv = getaddrinfo (candidate->ip, NULL, &hints, &res);
-  if (rv != 0)
+  addr = g_inet_address_new_from_string (candidate->ip);
+  if (addr == NULL)
   {
     g_set_error (error, FS_ERROR, FS_ERROR_INVALID_ARGUMENTS,
-        "Invalid address passed: %s", gai_strerror (rv));
+        "Invalid address passed: %s", candidate->ip);
     return FALSE;
   }
 
@@ -968,40 +945,30 @@ fs_rawudp_component_set_remote_candidate (FsRawUdpComponent *self,
     g_set_error (error, FS_ERROR, FS_ERROR_INVALID_ARGUMENTS,
         "Can't call set_remote_candidate after the thread has been stopped");
     FS_RAWUDP_COMPONENT_UNLOCK (self);
+    g_object_unref (addr);
     return FALSE;
   }
 
   if (self->priv->remote_candidate)
     fs_rawudp_transmitter_udpport_remove_known_address (self->priv->udpport,
-        &self->priv->remote_address, remote_is_unique_cb, self);
+        self->priv->remote_address, remote_is_unique_cb, self);
 
   old_candidate = self->priv->remote_candidate;
   self->priv->remote_candidate = fs_candidate_copy (candidate);
   sending = self->priv->sending;
 
-  switch (res->ai_family)
-  {
-    case AF_INET:
-      gst_netaddress_set_ip4_address (&self->priv->remote_address,
-          ((struct sockaddr_in *)res->ai_addr)->sin_addr.s_addr,
-          g_htons(candidate->port));
-      break;
-    case AF_INET6:
-      gst_netaddress_set_ip6_address (&self->priv->remote_address,
-          ((struct sockaddr_in6 *)res->ai_addr)->sin6_addr.s6_addr,
-          g_htons(candidate->port));
-      break;
-  }
+  g_clear_object (&self->priv->remote_address);
 
+  self->priv->remote_address = g_inet_socket_address_new (addr,
+      candidate->port);
+  g_object_unref (addr);
 
   self->priv->remote_is_unique =
     fs_rawudp_transmitter_udpport_add_known_address (self->priv->udpport,
-        &self->priv->remote_address, remote_is_unique_cb, self);
+        self->priv->remote_address, remote_is_unique_cb, self);
 
   FS_RAWUDP_COMPONENT_UNLOCK (self);
 
-  freeaddrinfo (res);
-
   if (sending)
     fs_rawudp_transmitter_udpport_add_dest (self->priv->udpport,
         candidate->ip, candidate->port);
@@ -1308,8 +1275,7 @@ fs_rawudp_component_start_stun (FsRawUdpComponent *self, GError **error)
   FS_RAWUDP_COMPONENT_LOCK (self);
   self->priv->stun_recv_id =
     fs_rawudp_transmitter_udpport_connect_recv (
-        self->priv->udpport,
-        G_CALLBACK (stun_recv_cb), self);
+      self->priv->udpport, stun_recv_cb, self);
 
 
   nice_address_init (&niceaddr);
@@ -1341,8 +1307,8 @@ fs_rawudp_component_start_stun (FsRawUdpComponent *self, GError **error)
       return FALSE;
     }
 
-    self->priv->stun_timeout_thread =
-      g_thread_create (stun_timeout_func, self, TRUE, error);
+    self->priv->stun_timeout_thread = g_thread_try_new ("stun timeout thread",
+        stun_timeout_func, self, error);
   }
 
   res = (self->priv->stun_timeout_thread != NULL);
@@ -1376,11 +1342,11 @@ fs_rawudp_component_stop_stun_locked (FsRawUdpComponent *self)
 
 
 
-static gboolean
-stun_recv_cb (GstPad *pad, GstBuffer *buffer,
-    gpointer user_data)
+static GstPadProbeReturn
+stun_recv_cb (GstPad *pad, GstPadProbeInfo *info, gpointer user_data)
 {
   FsRawUdpComponent *self = FS_RAWUDP_COMPONENT (user_data);
+  GstBuffer *buffer = GST_PAD_PROBE_INFO_BUFFER (info);
   FsCandidate *candidate = NULL;
   StunMessage msg;
   StunValidationStatus stunv;
@@ -1389,28 +1355,32 @@ stun_recv_cb (GstPad *pad, GstBuffer *buffer,
   socklen_t addr_len = sizeof(addr);
   struct sockaddr_storage alt_addr;
   socklen_t alt_addr_len = sizeof(alt_addr);
-  gchar addr_str[NI_MAXHOST];
+  gchar addr_str[NICE_ADDRESS_STRING_LEN + 1];
   NiceAddress niceaddr;
+  GstMapInfo map;
 
-  if (GST_BUFFER_SIZE (buffer) < 4)
+  gst_buffer_map (buffer, &map, GST_MAP_READ);
+
+  if (gst_buffer_get_size (buffer) < 4)
     /* Packet is too small to be STUN */
-    return TRUE;
+    goto passthrough;
 
-  if (GST_BUFFER_DATA (buffer)[0] >> 6)
+  if (map.data[0] >> 6)
     /* Non stun packet */
-    return TRUE;
+    goto passthrough;
 
 
   g_assert (fs_rawudp_transmitter_udpport_is_pad (self->priv->udpport, pad));
 
   FS_RAWUDP_COMPONENT_LOCK(self);
   stunv = stun_agent_validate (&self->priv->stun_agent, &msg,
-      GST_BUFFER_DATA (buffer), GST_BUFFER_SIZE (buffer), NULL, NULL);
+      map.data, map.size, NULL, NULL);
   FS_RAWUDP_COMPONENT_UNLOCK(self);
 
   /* not a valid stun message */
   if (stunv != STUN_VALIDATION_SUCCESS)
-    return TRUE;
+    goto passthrough;
+
 
   stunr = stun_usage_bind_process (&msg,
       (struct sockaddr *) &addr, &addr_len,
@@ -1483,7 +1453,14 @@ stun_recv_cb (GstPad *pad, GstBuffer *buffer,
 
   fs_candidate_destroy (candidate);
 
-  return FALSE;
+  gst_buffer_unmap (buffer, &map);
+
+  return GST_PAD_PROBE_DROP;
+
+passthrough:
+
+  gst_buffer_unmap (buffer, &map);
+  return GST_PAD_PROBE_OK;
 }
 
 static gpointer
@@ -1704,18 +1681,19 @@ fs_rawudp_component_emit_candidate (FsRawUdpComponent *self,
  * This is a has "have-data" signal handler, so we return %TRUE to not
  * drop the buffer
  */
-static gboolean
-buffer_recv_cb (GstPad *pad, GstBuffer *buffer, gpointer user_data)
+static GstPadProbeReturn
+buffer_recv_cb (GstPad *pad, GstPadProbeInfo *info, gpointer user_data)
 {
   FsRawUdpComponent *self = FS_RAWUDP_COMPONENT (user_data);
+  GstBuffer *buffer = GST_PAD_PROBE_INFO_BUFFER (info);
+  GstNetAddressMeta *netmeta = gst_buffer_get_net_address_meta (buffer);
 
-  if (GST_IS_NETBUFFER (buffer))
+  if (netmeta)
   {
-    GstNetBuffer *netbuffer = (GstNetBuffer*) buffer;
-
     FS_RAWUDP_COMPONENT_LOCK (self);
     if (self->priv->remote_is_unique &&
-        gst_netaddress_equal (&self->priv->remote_address, &netbuffer->from))
+        fs_g_inet_socket_address_equal (self->priv->remote_address,
+            netmeta->addr))
     {
       FS_RAWUDP_COMPONENT_UNLOCK (self);
       g_signal_emit (self, signals[KNOWN_SOURCE_PACKET_RECEIVED], 0,
@@ -1728,8 +1706,8 @@ buffer_recv_cb (GstPad *pad, GstBuffer *buffer, gpointer user_data)
   }
   else
   {
-    GST_WARNING ("received buffer thats not a NetBuffer");
+    GST_WARNING ("received buffer that does not contain a GstNetAddressMeta");
   }
 
-  return TRUE;
+  return GST_PAD_PROBE_OK;
 }
